@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Riverbank Computing Limited
+# Copyright (c) 2020, Riverbank Computing Limited
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,11 +27,16 @@
 # Publish the package's API.  These are for the tools.
 from .builder import Builder
 from .message_handler import MessageHandler
+from .platforms import Architecture
 from .project import Project
-from .sysroot import Sysroot
+from .sysroot import Sysroot, SysrootSpecification
 from .user_exception import UserException
 from .version import PYQTDEPLOY_RELEASE
 
 
 # These are for component plugins.
-from .sysroot import ComponentBase, ComponentOption
+from .parts import (ComponentLibrary, DataFile, ExtensionModule, PythonModule,
+        PythonPackage)
+from .sysroot import (AbstractComponent, AbstractPythonComponent,
+        AbstractPyQtComponent, AbstractQtComponent, AbstractSIPComponent,
+        Component, ComponentOption)
