@@ -42,25 +42,6 @@ class MessageHandler:
         self.quiet = quiet
         self.verbose = verbose
 
-    def progress_message(self, message):
-        """ Handle a progress message. """
-
-        if not self.quiet:
-            self.message(message)
-
-    def verbose_message(self, message):
-        """ Handle a verbose progress message. """
-
-        if self.verbose:
-            self.progress_message(message)
-
-    def message(self, message):
-        """ Handle a message.  This method may be reimplemented to send the
-        message to somewhere other that stdout.
-        """
-
-        print(message, flush=True)
-
     @classmethod
     def error(cls, message):
         """ Handle an error message. """
@@ -72,6 +53,32 @@ class MessageHandler:
         """ Handle an exception. """
 
         if self.verbose and e.detail != '':
-            self.error("{0}: {1}".format(e.text, e.detail))
+            self.error("{0}: {1}".format(e.text[:-1], e.detail))
         else:
             self.error(e.text)
+
+    def message(self, message):
+        """ Handle a message.  This method may be reimplemented to send the
+        message to somewhere other that stdout.
+        """
+
+        print(message, flush=True)
+
+    def progress_message(self, message):
+        """ Handle a progress message. """
+
+        if not self.quiet:
+            # There should already be one trailing period.
+            self.message(message + '..')
+
+    def verbose_message(self, message):
+        """ Handle a verbose progress message. """
+
+        if self.verbose and not self.quiet:
+            self.message(message)
+
+    def warning(self, message):
+        """ Handle a warning message. """
+
+        if not self.quiet:
+            self.message("WARNING: " + message)
