@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Riverbank Computing Limited
+# Copyright (c) 2020, Riverbank Computing Limited
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -25,5 +25,12 @@
 
 
 # Publish the sub-package's API.
-from .component import ComponentBase, ComponentOption
+from .abstract_component import AbstractComponent
+from .abstract_pyqt_component import AbstractPyQtComponent
+from .abstract_python_component import AbstractPythonComponent
+from .abstract_qt_component import AbstractQtComponent
+from .abstract_sip_component import AbstractSIPComponent
+from .component import Component
+from .component_option import ComponentOption
+from .specification import SysrootSpecification
 from .sysroot import Sysroot
